@@ -1,31 +1,31 @@
 import logging
 import os
-from pathlib import Path
 import tempfile
+from pathlib import Path
 from typing import List
 
 from .. import BaseRunner
 
 log = logging.getLogger()
 
-DEFAULT_BFLAGS: List[str] = ['']
+DEFAULT_BFLAGS: List[str] = [""]
 
 
 class Runner(BaseRunner):
 
-    log_prefix = 'go-kernel'
-    default_runtime_path = '/usr/local/bin/go'
+    log_prefix = "go-kernel"
+    default_runtime_path = "/usr/local/bin/go"
     default_child_env = {
-        'TERM': 'xterm',
-        'LANG': 'C.UTF-8',
-        'SHELL': '/bin/ash',
-        'USER': 'work',
-        'HOME': '/home/work',
-        'PATH': '/home/work/bin:/go/bin:/usr/local/go/bin:' +
-                '/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin',
-        'GOPATH': '/home/work',
-        'LD_LIBRARY_PATH': os.environ.get('LD_LIBRARY_PATH', ''),
-        'LD_PRELOAD': os.environ.get('LD_PRELOAD', ''),
+        "TERM": "xterm",
+        "LANG": "C.UTF-8",
+        "SHELL": "/bin/ash",
+        "USER": "work",
+        "HOME": "/home/work",
+        "PATH": "/home/work/bin:/go/bin:/usr/local/go/bin:"
+        + "/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin",
+        "GOPATH": "/home/work",
+        "LD_LIBRARY_PATH": os.environ.get("LD_LIBRARY_PATH", ""),
+        "LD_PRELOAD": os.environ.get("LD_PRELOAD", ""),
     }
 
     def __init__(self, *args, **kwargs):
@@ -35,12 +35,15 @@ class Runner(BaseRunner):
         pass
 
     async def build_heuristic(self) -> int:
-        if Path('main.go').is_file():
-            go_glob = Path('.').glob('**/*.go')
+        if Path("main.go").is_file():
+            go_glob = Path(".").glob("**/*.go")
             cmd = [
                 str(self.runtime_path),
-                'build', '-o', 'main',
-                *DEFAULT_BFLAGS, *map(str, go_glob),
+                "build",
+                "-o",
+                "main",
+                *DEFAULT_BFLAGS,
+                *map(str, go_glob),
             ]
             return await self.run_subproc(cmd)
         else:
@@ -48,17 +51,17 @@ class Runner(BaseRunner):
             return 127
 
     async def execute_heuristic(self) -> int:
-        if Path('./main').is_file():
-            return await self.run_subproc('./main')
+        if Path("./main").is_file():
+            return await self.run_subproc("./main")
         else:
             log.error('cannot find executable ("main").')
             return 127
 
     async def query(self, code_text) -> int:
-        with tempfile.NamedTemporaryFile(suffix='.go', dir='.') as tmpf:
-            tmpf.write(code_text.encode('utf8'))
+        with tempfile.NamedTemporaryFile(suffix=".go", dir=".") as tmpf:
+            tmpf.write(code_text.encode("utf8"))
             tmpf.flush()
-            cmd = [str(self.runtime_path), 'run', tmpf.name]
+            cmd = [str(self.runtime_path), "run", tmpf.name]
             return await self.run_subproc(cmd)
 
     async def complete(self, data):
